Test data folder

testensemble-reek001 is copied from /scratch/fmu/havb/2_r001_reek and then
stripped for all RMS input/output, all Eclipse input/output except UNSMRY
and most other noisy data from the Ert run. Can be used to verify
loading of ensembles, processing the STATUS file, parameters.txt,
UNSMRY and volumetrics text files from RMS
